@@ -9,7 +9,7 @@
 # 
 package Config::Model::Tk::ListViewer ;
 BEGIN {
-  $Config::Model::Tk::ListViewer::VERSION = '1.314';
+  $Config::Model::Tk::ListViewer::VERSION = '1.315';
 }
 
 use strict;
@@ -53,7 +53,7 @@ sub Populate {
 				     -height => 10,
 				   ) ->pack(@fbe1) ;
 
-    my @insert = $list->cargo_type eq 'leaf' ? $list->fetch_all_values 
+    my @insert = $list->cargo_type eq 'leaf' ? $list->fetch_all_values (check => 'no')
                :                         $list->get_all_indexes ;
     foreach my $c (@insert) {
 	my $line = defined $c ? $c : '<undef>' ;
