@@ -9,7 +9,7 @@
 # 
 package Config::Model::Tk::NodeEditor ;
 BEGIN {
-  $Config::Model::Tk::NodeEditor::VERSION = '1.314';
+  $Config::Model::Tk::NodeEditor::VERSION = '1.315';
 }
 
 use strict;
@@ -110,7 +110,7 @@ sub fill_pane {
 
 	if ($type eq 'leaf') {
 	    my $leaf = $node->fetch_element($c) ;
-	    my $v = eval {$node->fetch_element_value($c)} ;
+	    my $v = $node->fetch_element_value(name => $c, check  => 'no') ;
 	    my $store_sub = sub {$leaf->store($v); 
 				 $cw->{store_cb}->(1,undef,$elt_path);
 				 $cw->fill_pane;
